@@ -1,59 +1,58 @@
 #
-# $Id: Offline.pm 328 2011-01-13 10:19:33Z gomor $
+# $Id: Offline.pm 353 2012-09-12 18:15:33Z gomor $
 #
 package Net::Frame::Dump::Offline;
 use strict;
 use warnings;
 
-use Net::Frame::Dump qw(:consts);
-our @ISA = qw(Net::Frame::Dump);
+use base qw(Net::Frame::Dump);
 __PACKAGE__->cgBuildIndices;
 
-no strict 'vars';
+use Net::Frame::Dump qw(:consts);
 
-use Carp;
 use Net::Pcap;
 use Time::HiRes qw(gettimeofday);
 
-sub new { shift->_dumpNew(@_) }
-
 sub _openFile {
    my $self = shift;
 
    my $err;
-   $self->[$___pcapd] = Net::Pcap::open_offline($self->[$__file], \$err);
-   unless ($self->[$___pcapd]) {
-      warn("@{[(caller(0))[3]]}: Net::Pcap::open_offline: ".
-           "@{[$self->[$__file]]}: $err\n");
+   my $pcapd = Net::Pcap::open_offline($self->file, \$err);
+   if (!defined($pcapd)) {
+      print("[-] ".__PACKAGE__.": Net::Pcap::open_offline: ".
+            "@{[$self->file]}: $err\n");
       return;
    }
+   $self->_pcapd($pcapd);
 
-   $self->_dumpGetFirstLayer;
+   return $self->getFirstLayer;
 }
 
 sub _setFilter {
    my $self = shift;
-   my $str = $self->[$__filter];
 
-   return unless $str;
-
-   my $filter;
-   Net::Pcap::compile($self->[$___pcapd], \$filter, $str, 0, 0);
-   unless ($filter) {
-      warn("@{[(caller(0))[3]]}: Net::Pcap::compile: error\n");
+   my $str = $self->filter;
+   if (!defined($str)) {
       return;
    }
 
-   Net::Pcap::setfilter($self->[$___pcapd], $filter);
+   my $filter;
+   Net::Pcap::compile($self->_pcapd, \$filter, $str, 0, 0);
+   if (!defined($filter)) {
+      print("[-] ".__PACKAGE__.": Net::Pcap::compile: error\n");
+      return;
+   }
+
+   Net::Pcap::setfilter($self->_pcapd, $filter);
 }
 
 sub start {
    my $self = shift;
 
-   $self->[$__isRunning] = 1;
+   $self->isRunning(1);
 
-   if (! -f $self->[$__file]) {
-      warn("File does not exists: ".$self->[$__file]."\n");
+   if (! -f $self->file) {
+      print("[-] ".__PACKAGE__.": File does not exists: ".$self->file."\n");
       return;
    }
 
@@ -66,19 +65,17 @@ sub start {
 sub stop {
    my $self = shift;
 
-   return unless $self->[$__isRunning];
+   if (!$self->isRunning) {
+      return;
+   }
 
-   Net::Pcap::close($self->[$___pcapd]);
-   $self->[$__isRunning] = 0;
+   Net::Pcap::close($self->_pcapd);
+   $self->_pcapd(undef);
+   $self->isRunning(0);
 
    return 1;
 }
 
-sub next         { shift->_dumpPcapNext(@_)     }
-sub getFramesFor { shift->_dumpGetFramesFor(@_) }
-sub store        { shift->_dumpStore(@_)        }
-sub flush        { shift->_dumpFlush(@_)        }
-
 1;
 
 __END__
@@ -202,7 +199,7 @@ Patrice E<lt>GomoRE<gt> Auffret
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2006-2011, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2006-2012, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of the Artistic license.
 See LICENSE.Artistic file in the source distribution archive.
